rekha.plots.LinePlot
====================

.. currentmodule:: rekha.plots

.. autoclass:: LinePlot

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~LinePlot.add_annotation
      ~LinePlot.get_axes
      ~LinePlot.save
      ~LinePlot.save_all_formats
      ~LinePlot.show
      ~LinePlot.show_legend
      ~LinePlot.update_layout
   
   

   
   
   